AnomalyDetector class

An anomaly detection model associated with a particular CloudWatch metric and statistic. You can use the model to display a band of expected normal values when the metric is graphed.

Constructors

AnomalyDetector({AnomalyDetectorConfiguration? configuration, List<Dimension>? dimensions, String? metricName, String? namespace, String? stat, AnomalyDetectorStateValue? stateValue})
AnomalyDetector.fromXml(XmlElement elem)
factory

Properties

configuration → AnomalyDetectorConfiguration?
The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude from use for training the model, and the time zone to use for the metric.
final
dimensions → List<Dimension>?
The metric dimensions associated with the anomaly detection model.
final
hashCode → int
The hash code for this object.
no setterinherited
metricName → String?
The name of the metric associated with the anomaly detection model.
final
namespace → String?
The namespace of the metric associated with the anomaly detection model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stat → String?
The statistic associated with the anomaly detection model.
final
stateValue → AnomalyDetectorStateValue?
The current status of the anomaly detector's training. The possible values are TRAINED | PENDING_TRAINING | TRAINED_INSUFFICIENT_DATA
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited