DashboardValidationMessage class

An error or warning for the operation.

Constructors

DashboardValidationMessage({String? dataPath, String? message})
DashboardValidationMessage.fromXml(XmlElement elem)
factory

Properties

dataPath → String?
The data path related to the message.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A message describing the error or warning.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited