Datapoint class

Encapsulates the statistical data that CloudWatch computes from metric data.

Constructors

Datapoint({double? average, Map<String, double>? extendedStatistics, double? maximum, double? minimum, double? sampleCount, double? sum, DateTime? timestamp, StandardUnit? unit})
Datapoint.fromXml(XmlElement elem)
factory

Properties

average → double?
The average of the metric values that correspond to the data point.
final
extendedStatistics → Map<String, double>?
The percentile statistic for the data point.
final
hashCode → int
The hash code for this object.
no setterinherited
maximum → double?
The maximum metric value for the data point.
final
minimum → double?
The minimum metric value for the data point.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleCount → double?
The number of metric values that contributed to the aggregate value of this data point.
final
sum → double?
The sum of the metric values for the data point.
final
timestamp → DateTime?
The time stamp used for the data point.
final
unit → StandardUnit?
The standard unit for the data point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited