DescribeAnomalyDetectorsOutput class

Constructors

DescribeAnomalyDetectorsOutput({List<AnomalyDetector>? anomalyDetectors, String? nextToken})
DescribeAnomalyDetectorsOutput.fromXml(XmlElement elem)
factory

Properties

anomalyDetectors → List<AnomalyDetector>?
The list of anomaly detection models returned by the operation.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
A token that you can use in a subsequent operation to retrieve the next set of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited