DescribeInsightRulesOutput class

Constructors

DescribeInsightRulesOutput({List<InsightRule>? insightRules, String? nextToken})
DescribeInsightRulesOutput.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
insightRules → List<InsightRule>?
The rules returned by the operation.
final
nextToken → String?
If this parameter is present, it is a token that marks the start of the next batch of returned results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited