GetInsightRuleReportOutput class

Constructors

GetInsightRuleReportOutput({double? aggregateValue, String? aggregationStatistic, int? approximateUniqueCount, List<InsightRuleContributor>? contributors, List<String>? keyLabels, List<InsightRuleMetricDatapoint>? metricDatapoints})
GetInsightRuleReportOutput.fromXml(XmlElement elem)
factory

Properties

aggregateValue → double?
The sum of the values from all individual contributors that match the rule.
final
aggregationStatistic → String?
Specifies whether this rule aggregates contributor data by COUNT or SUM.
final
approximateUniqueCount → int?
An approximate count of the unique contributors found by this rule in this time period.
final
contributors → List<InsightRuleContributor>?
An array of the unique contributors found by this rule in this time period. If the rule contains multiple keys, each combination of values for the keys counts as a unique contributor.
final
hashCode → int
The hash code for this object.
no setterinherited
keyLabels → List<String>?
An array of the strings used as the keys for this rule. The keys are the dimensions used to classify contributors. If the rule contains more than one key, then each unique combination of values for the keys is counted as a unique contributor.
final
metricDatapoints → List<InsightRuleMetricDatapoint>?
A time series of metric data points that matches the time period in the rule request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited