InsightRule class

This structure contains the definition for a Contributor Insights rule.

Constructors

InsightRule({required String definition, required String name, required String schema, required String state})
InsightRule.fromXml(XmlElement elem)
factory

Properties

definition → String
The definition of the rule, as a JSON object. The definition contains the keywords used to define contributors, the value to aggregate on if this rule returns a sum instead of a count, and the filters. For details on the valid syntax, see Contributor Insights Rule Syntax.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String
For rules that you create, this is always {"Name": "CloudWatchLogRule", "Version": 1}. For built-in rules, this is {"Name": "ServiceLogRule", "Version": 1}
final
state → String
Indicates whether the rule is enabled or disabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited