InsightRuleMetricDatapoint class

One data point from the metric time series returned in a Contributor Insights rule report.

For more information, see GetInsightRuleReport.

Constructors

InsightRuleMetricDatapoint({required DateTime timestamp, double? average, double? maxContributorValue, double? maximum, double? minimum, double? sampleCount, double? sum, double? uniqueContributors})
InsightRuleMetricDatapoint.fromXml(XmlElement elem)
factory

Properties

average → double?
The average value from all contributors during the time period represented by that data point.
final
hashCode → int
The hash code for this object.
no setterinherited
maxContributorValue → double?
The maximum value provided by one contributor during this timestamp. Each timestamp is evaluated separately, so the identity of the max contributor could be different for each timestamp.
final
maximum → double?
The maximum value from a single occurence from a single contributor during the time period represented by that data point.
final
minimum → double?
The minimum value from a single contributor during the time period represented by that data point.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleCount → double?
The number of occurrences that matched the rule during this data point.
final
sum → double?
The sum of the values from all contributors during the time period represented by that data point.
final
timestamp → DateTime
The timestamp of the data point.
final
uniqueContributors → double?
The number of unique contributors who published data during this timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited