Metric class

Represents a specific metric.

Constructors

Metric({List<Dimension>? dimensions, String? metricName, String? namespace})
Metric.fromXml(XmlElement elem)
factory

Properties

dimensions → List<Dimension>?
The dimensions for the metric.
final
hashCode → int
The hash code for this object.
no setterinherited
metricName → String?
The name of the metric. This is a required field.
final
namespace → String?
The namespace of the metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited