MetricStat class

This structure defines the metric to be returned, along with the statistics, period, and units.

Constructors

MetricStat({required Metric metric, required int period, required String stat, StandardUnit? unit})
MetricStat.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metric → Metric
The metric to return, including the metric name, namespace, and dimensions.
final
period → int
The granularity, in seconds, of the returned data points. For metrics with regular resolution, a period can be as short as one minute (60 seconds) and must be a multiple of 60. For high-resolution metrics that are collected at intervals of less than one minute, the period can be 1, 5, 10, 30, 60, or any multiple of 60. High-resolution metrics are those metrics stored by a PutMetricData call that includes a StorageResolution of 1 second.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stat → String
The statistic to return. It can include any CloudWatch statistic or extended statistic.
final
unit → StandardUnit?
When you are using a Put operation, this defines what unit you want to use when storing the metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited