PartialFailure class

This array is empty if the API operation was successful for all the rules specified in the request. If the operation could not process one of the rules, the following data is returned for each of those rules.

Constructors

PartialFailure({String? exceptionType, String? failureCode, String? failureDescription, String? failureResource})
PartialFailure.fromXml(XmlElement elem)
factory

Properties

exceptionType → String?
The type of error.
final
failureCode → String?
The code of the error.
final
failureDescription → String?
A description of the error.
final
failureResource → String?
The specified rule that could not be deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited