StatisticSet class

Represents a set of statistics that describes a specific metric.

Constructors

StatisticSet({required double maximum, required double minimum, required double sampleCount, required double sum})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximum → double
The maximum value of the sample set.
final
minimum → double
The minimum value of the sample set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleCount → double
The number of samples used for the statistic set.
final
sum → double
The sum of values for the sample set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited